/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */

"use strict";

/* import-globals-from ../../mochitest/layout.js */
loadScripts({ name: "layout.js", dir: MOCHITESTS_DIR });

async function runTests(browser, accDoc) {
  await loadContentScripts(browser, {
    script: "Layout.jsm",
    symbol: "Layout",
  });

  let paragraph = findAccessibleChildByID(accDoc, "paragraph", [
    nsIAccessibleText,
  ]);
  let offset = 64; // beginning of 4th stanza

  let [x /* ,y*/] = getPos(paragraph);
  let [docX, docY] = getPos(accDoc);

  paragraph.scrollSubstringToPoint(
    offset,
    offset,
    COORDTYPE_SCREEN_RELATIVE,
    docX,
    docY
  );

  await waitForContentPaint(browser);
  testTextPos(paragraph, offset, [x, docY], COORDTYPE_SCREEN_RELATIVE);

  await SpecialPowers.spawn(browser, [], () => {
    content.Layout.zoomDocument(content.document, 2.0);
  });

  paragraph = findAccessibleChildByID(accDoc, "paragraph2", [
    nsIAccessibleText,
  ]);
  offset = 52; // // beginning of 4th stanza
  [x /* ,y*/] = getPos(paragraph);
  paragraph.scrollSubstringToPoint(
    offset,
    offset,
    COORDTYPE_SCREEN_RELATIVE,
    docX,
    docY
  );

  await waitForContentPaint(browser);
  testTextPos(paragraph, offset, [x, docY], COORDTYPE_SCREEN_RELATIVE);
}

/**
 * Test caching of accessible object states
 */
addAccessibleTask(
  `
  <br><br><br><br><br><br><br><br><br><br>
  <br><br><br><br><br><br><br><br><br><br>
  <br><br><br><br><br><br><br><br><br><br>
  <br><br><br><br><br><br><br><br><br><br>
  <br><br><br><br><br><br><br><br><br><br>
  <br><br><br><br><br><br><br><br><br><br>
  <br><br><br><br><br><br><br><br><br><br>
  <br><br><br><br><br><br><br><br><br><br>
  <br><br><br><br><br><br><br><br><br><br>
  <br><br><br><br><br><br><br><br><br><br>
  <br><br><br><br><br><br><br><br><br><br>
  <br><br><br><br><br><br><br><br><br><br>
  <br><br><br><br><br><br><br><br><br><br>
  <br><br><br><br><br><br><br><br><br><br>
  <br><br><br><br><br><br><br><br><br><br>
  <br><br><br><br><br><br><br><br><br><br>
  <br><br><br><br><br><br><br><br><br><br>
  <br><br><br><br><br><br><br><br><br><br>
  <br><br><br><br><br><br><br><br><br><br>
  <br><br><br><br><br><br><br><br><br><br>
  <br><br><br><br><br><br><br><br><br><br>
  <br><br><br><br><br><br><br><br><br><br>
  <br><br><br><br><br><br><br><br><br><br>
  <br><br><br><br><br><br><br><br><br><br>
  <br><br><br><br><br><br><br><br><br><br>
  <br><br><br><br><br><br><br><br><br><br>
  <br><br><br><br><br><br><br><br><br><br>
  <br><br><br><br><br><br><br><br><br><br>
  <br><br><br><br><br><br><br><br><br><br>
  <br><br><br><br><br><br><br><br><br><br>
  <br><br><br><br><br><br><br><br><br><br>
  <br><br><br><br><br><br><br><br><br><br>
  <br><br><br><br><br><br><br><br><br><br>
  <br><br><br><br><br><br><br><br><br><br><hr>
  <p id='paragraph'>
    Пошел котик на торжок<br>
    Купил котик пирожок<br>
    Пошел котик на улочку<br>
    Купил котик булочку<br>
  </p>
  <hr><br><br><br><br><br><br><br><br><br><br>
  <br><br><br><br><br><br><br><br><br><br>
  <br><br><br><br><br><br><br><br><br><br>
  <br><br><br><br><br><br><br><br><br><br>
  <br><br><br><br><br><br><br><br><br><br>
  <br><br><br><br><br><br><br><br><br><br><hr>
  <p id='paragraph2'>
    Самому ли съесть<br>
    Либо Сашеньке снесть<br>
    Я и сам укушу<br>
    Я и Сашеньке снесу<br>
  </p>
  <hr><br><br><br><br><br><br><br><br><br><br>
  <br><br><br><br><br><br><br><br><br><br>
  <br><br><br><br><br><br><br><br><br><br>
  <br><br><br><br><br><br><br><br><br><br>
  <br><br><br><br><br><br><br><br><br><br>
  <br><br><br><br><br><br><br><br><br><br>
  <br><br><br><br><br><br><br><br><br><br>
  <br><br><br><br><br><br><br><br><br><br>
  <br><br><br><br><br><br><br><br><br><br>
  <br><br><br><br><br><br><br><br><br><br>
  <br><br><br><br><br><br><br><br><br><br>
  <br><br><br><br><br><br><br><br><br><br>
  <br><br><br><br><br><br><br><br><br><br>
  <br><br><br><br><br><br><br><br><br><br>
  <br><br><br><br><br><br><br><br><br><br>
  <br><br><br><br><br><br><br><br><br><br>
  <br><br><br><br><br><br><br><br><br><br>
  <br><br><br><br><br><br><br><br><br><br>
  <br><br><br><br><br><br><br><br><br><br>
  <br><br><br><br><br><br><br><br><br><br>
  <br><br><br><br><br><br><br><br><br><br>
  <br><br><br><br><br><br><br><br><br><br>
  <br><br><br><br><br><br><br><br><br><br>
  <br><br><br><br><br><br><br><br><br><br>
  <br><br><br><br><br><br><br><br><br><br>
  <br><br><br><br><br><br><br><br><br><br>
  <br><br><br><br><br><br><br><br><br><br>
  <br><br><br><br><br><br><br><br><br><br>
  <br><br><br><br><br><br><br><br><br><br>
  <br><br><br><br><br><br><br><br><br><br>
  <br><br><br><br><br><br><br><br><br><br>`,
  runTests
);
